@@ -6,7 +6,9 @@ use warnings;
 
 our $VERSION;
 #$VERSION = sprintf "%d.%02d", q$Name: Release-0-28 $ =~ /Release-(\d+)-(\d+)/;
-$VERSION = sprintf "%s", q$Name: Release-v0.303.0$ =~ /Release-(v\d+\.\d+\.\d+)/;
+$VERSION = sprintf "%s", q$Name: Release-v0.304.0$ =~ /Release-(v\d+\.\d+\.\d+)/;
+our $NVERSION;			# pure numeric 2-part equivalent version
+($NVERSION = $VERSION) =~ s/v(\d+\.\d+)\.\d+/$1/;
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -14,9 +16,8 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw();
 our @EXPORT_OK = qw(
 	id2ppath ppath2id s2ppchars id2pairpath pairpath2id
-	pt_lsnode pt_lstree pt_mknode pt_mktree pt_rmnode
-	pt_mkbud
-	get_prefix
+	pt_lsbud pt_lstree pt_mkbud pt_mktree pt_rmbud
+	pt_budstr get_prefix
 	$pfixtail
 	$pair $pairp1 $pairm1
 );
@@ -27,15 +28,6 @@ our @EXPORT_FAIL = qw(
 );
 push @EXPORT_OK, @EXPORT_FAIL;		# add pseudo-symbols we will trap
 
-#our @EXPORT = qw(
-#	id2ppath ppath2id s2ppchars id2pairpath pairpath2id
-#	pt_lsnode pt_lstree pt_mknode pt_mktree pt_rmnode
-#	pt_mkbud
-#	get_prefix
-#	$pfixtail
-#	$pair $pairp1 $pairm1
-#);
-
 # This is a magic routine that the Exporter calls for any unknown symbols.
 # We use it to permit export of pseudo-symbols "pair=1", "pair=2", ...,
 # "pair=9" so the caller can define a pair to mean 1, 2, ..., or 9 octets.
@@ -94,22 +86,6 @@ my $P = $proper_ppath_re;
 # $pt_objid =~ tr/\/:./=+,/;
 # my $pt_prefix = $namespace."/pairtree_root/".join('/', $pt_objid =~ /..|.$/g);
 
-# ---------
-# Copyright 2008-2009 Regents of the University of California
-# 
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain a
-# copy of the License at
-# 
-#         http://www.apache.org/licenses/LICENSE-2.0
-# 
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License. 
-# ---------
-
 # id2ppath - return /-terminated ppath corresponding to id
 # 
 # For Perl, the platform's path component separator ('/' or '\') is
@@ -262,23 +238,11 @@ use Carp;
 use File::Spec;
 use File::Find;
 use File::Path;
-#use File::ANVL;
 use File::Namaste qw( nam_add );
 use File::Value ':all';
 use File::Glob ':glob';		# standard use of module, which we need
 				# as vanilla glob won't match whitespace
 
-## Return parent with trailing slash intact.
-##
-#sub up_dir { ( $_ )=@_;
-#
-#	return "/"		if m,^/+$,;
-#	return "./"		if m,^\./*$,;
-#	s,[^/]+/*$,,;
-#	return "./"		if m,^$,;
-#	return $_;
-#}
-
 our $Win;			# whether we're running on Windows
 
 my $pfixtail = 'pairtree_prefix';
@@ -299,13 +263,14 @@ sub get_prefix { my( $parent_dir )=@_;
 # return 0 on success, 1 on soft fail, >1 on hard fail
 # xxxxxxxxx get consistent on these return codes/croaks
 #
-sub pt_lsnode { my( $dir, $id, $r_opt )=@_;
+sub pt_lsbud { my( $dir, $id, $r_opt )=@_;
 
 	$dir		or croak "no dir or empty dir";
 	$id		or croak "no id or empty id";
 	ref($r_opt) eq "HASH" or
 		croak "r_opt must reference a hash (for input/output)";
 
+	$dir = fiso_dname($dir, $R);	# make sure we have descender
 	my $parent_dir = $$r_opt{parent_dir}
 		|| fiso_uname($dir);
 	my $prefix = $$r_opt{prefix}
@@ -375,6 +340,7 @@ sub pt_lstree { my( $tree, $r_opt, $r_visit_node, $r_wrapup )=@_;
 	defined($Win) or	# if we're on a Windows platform avoid -l
 		$Win = grep(/Win32|OS2/i, @File::Spec::ISA);
 
+	$tree = fiso_dname($tree, $R);	# make sure we have descender
 	$$r_opt{parent_dir} ||= fiso_uname($tree);
 	$$r_opt{prefix} ||= get_prefix($$r_opt{prefix});
 
@@ -401,9 +367,9 @@ sub pt_lstree { my( $tree, $r_opt, $r_visit_node, $r_wrapup )=@_;
 	return $ret;
 }
 
-# Create the bud that will encapsulate the leaf node
+# Create the bud string that will encapsulate the leaf node
 #
-sub pt_mkbud { my( $id, $bud_style )=@_;
+sub pt_budstr { my( $id, $bud_style )=@_;
 
 	# Xxx add chars if less than $pair chars in $_
 	$id ||= "";
@@ -423,13 +389,14 @@ sub pt_mkbud { my( $id, $bud_style )=@_;
 	return s2ppchars($id);
 }
 
-sub pt_mknode { my( $dir, $id, $r_opt )=@_;
+sub pt_mkbud { my( $dir, $id, $r_opt )=@_;
 
 	$dir		or croak "no dir or empty dir";
 	$id		or croak "no id or empty id";
 	ref($r_opt) eq "HASH" or
 		croak "r_opt must reference a hash (for input/output)";
 
+	$dir = fiso_dname($dir, $R);	# make sure we have descender
 	my $parent_dir = $$r_opt{parent_dir}
 		|| fiso_uname($dir);
 	my $prefix = $$r_opt{prefix}
@@ -444,16 +411,16 @@ sub pt_mknode { my( $dir, $id, $r_opt )=@_;
 
 	-d $dir or			# need to create base directory
 		pt_mktree($dir, "", $r_opt) and		# if error
-		($$r_opt{msg} = "pt_mknode: $$r_opt{msg}"),
+		($$r_opt{msg} = "pt_mkbud: $$r_opt{msg}"),
 		return 1;		# return after adding our stamp
 	my $ppath = $parent_dir . id2ppath($id);
-	my $bud = $ppath . pt_mkbud($id, $$r_opt{bud_style});
+	my $bud = $ppath . pt_budstr($id, $$r_opt{bud_style});
 
 	my $ret;
 	eval { $ret = mkpath($bud) };
 	$@		and croak "Couldn't create $bud: $@";
 	if ($ret == 0) {
-		croak "pt_mknode: mkpath returned '0' for $bud"
+		croak "pt_mkbud: mkpath returned '0' for $bud"
 			unless -e $bud;
 		$$r_opt{msg} = "error: $bud ($id) already exists\n";
 		return 0;
@@ -474,6 +441,7 @@ sub pt_mktree { my( $dir, $prefix, $r_opt )=@_;
 		croak "r_opt must reference a hash (for input/output)";
 			# except that we ignore any r_opt inputs here
 
+	$dir = fiso_dname($dir, $R);	# make sure we have descender
 	my $parent_dir = fiso_uname($dir);
 	my $ret;
 	eval { $ret = mkpath($dir) };
@@ -494,22 +462,24 @@ sub pt_mktree { my( $dir, $prefix, $r_opt )=@_;
 		$$r_opt{msg} = "$pxfile: $msg";
 		return 1;
 	}
-	$msg = nam_add($dir, undef, '0', "pairtree_$VERSION",
-		# xxx better to use 0 to mean "don't truncate"
-		length("pairtree_$VERSION"));
-	# xxxx croak or return via r_opt{msg}
 	$msg		and croak "Couldn't create namaste tag in $dir: $msg";
+	$msg = nam_add($parent_dir, undef, '0', "pairtree_$NVERSION", 0);
+		# yyy better to use 0 to mean "don't truncate"
+		#length("pairtree_$VERSION"));
+	# xxxx croak or return via r_opt{msg}
+	$msg	and croak "Couldn't create namaste tag in $parent_dir: $msg";
 
 	return 0;
 }
 
-sub pt_rmnode { my( $dir, $id, $r_opt )=@_;
+sub pt_rmbud { my( $dir, $id, $r_opt )=@_;
 
 	$dir		or croak "no dir or empty dir";
 	$id		or croak "no id or empty id";
 	ref($r_opt) eq "HASH" or
 		croak "r_opt must reference a hash (for input/output)";
 
+	$dir = fiso_dname($dir, $R);	# make sure we have descender
 	my $parent_dir = $$r_opt{parent_dir}
 		|| fiso_uname($dir);
 	my $prefix = $$r_opt{prefix}
@@ -709,11 +679,11 @@ File::Pairtree - routines to manage pairtrees
  ppath2id($path);              # returns id corresponding to $path
  ppath2id($path, $separator);  # if you want an alternate separator char
 
+ pt_budstr();
  pt_mkbud();
- pt_mknode();
  pt_mktree();
- pt_rmnode();
- pt_lsnode();
+ pt_rmbud();
+ pt_lsbud();
 
 =head1 DESCRIPTION
 
@@ -721,7 +691,7 @@ This is very brief documentation for the B<Pairtree> Perl module.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2010 UC Regents.  Open source BSD license.
+Copyright 2008-2011 UC Regents.  Open source BSD license.
 
 =cut
 
